@@ -71,7 +71,7 @@ def extractVersionRequirement(text):
   minimumVersion = re.search('<<MinimumVersion:\s*([0-9.]*)>>|$', text).group(1)
   return minimumVersion
 
-def init(data):
+def init(data, baseDirectory):
   """
   runs a script (typically init.py) and catches its stdout and stderr in a .log file.
   """
@@ -149,34 +149,36 @@ def main():
     # folders they are in.
     # TODO path is incorrect
     baseFolder = os.path.join(baseDirectory, 'manuscripts')
-    filelist = []
+    fileList = []
     for filename in glob.glob(f'{baseFolder}/**/init.py', recursive = True):
       scriptname = os.path.basename(filename)
       folder = os.path.dirname(filename)
-      filelist.append((folder, scriptname))
+      fileList.append((folder, scriptname))
 
     # Get the number of CPUs for parallel processing.
     nCpu = cpu_count()
 
     # Execute all scripts in parallel (by calling the init function) and catch
     # their return values.
+    from IPython import embed
+    embed()
     with Pool(nCpu) as p:
-      returnValues = p.map(init, filelist)
+      returnValues = p.map(init, fileList, baseDirectory)
 
       # Filter the return values for failed scripts.
-      failedlist = [(x[1], x[2], x[3]) for x in returnValues if not x[0]]
+      failedList = [(x[1], x[2], x[3]) for x in returnValues if not x[0]]
 
       # Try the scripts which failed again.
-      returnValues = p.map(init, failedlist)
+      returnValues = p.map(init, failedList)
 
       # Filter the return values for failed scripts.
-      failedlist = [(x[1], x[2], x[3]) for x in returnValues if not x[0]]
+      failedList = [(x[1], x[2], x[3]) for x in returnValues if not x[0]]
 
       # Show the scripts which failed twice.
-      if len(failedlist) > 0:
+      if len(failedList) > 0:
         print()
         print('The following scripts failed twice:')
-        for item in failedlist:
+        for item in failedList:
           print('{0:s}/{1:s}'.format(item[0], item[1]))
           print('See {0:s} for details.'.format(item[2]))
         print('Associated templates will not be available.')
@@ -219,9 +221,6 @@ def main():
       templateUsesBibLaTeX = '<<BibLaTeXResources>>' in templateFileData
 
       # Collect the information in the template list.
-      # TODO
-      from IPython import embed
-      embed()
       templateList.append([templateBaseName, 
         templateUsesBibLaTeX, 
         templateDescription, 
@@ -339,7 +338,6 @@ def main():
   templateFile = templatePrefix + templateBaseName 
 
   # Try to locate the unique .tex template file to be used.
-  # TODO: Path
   templateFile = glob.glob(baseDirectory + '/**/' + templateFile + '.tex', recursive = True)
   if len(templateFile) == 0:
     print("No template file matching '{templateBaseName:s}' was found in the current directory.".format(templateBaseName = templateBaseName))
@@ -458,8 +456,7 @@ def main():
   quietprint("Template description: {description:s}".format(description = templateDescription))
 
   # Import the rules file, which is supposed to provide functions to fill in the placeholders present in the template.
-  # TODO
-  spec = importlib.util.spec_from_file_location("", rulesFile)
+  spec = importlib.util.spec_from_file_location("scoop template engine rules", rulesFile)
   rules = importlib.util.module_from_spec(spec)
   spec.loader.exec_module(rules)
 
